@@ -12,6 +12,7 @@ module Either = Either
 module Exn = Exn
 module Exn_with_backtrace = Exn_with_backtrace
 module Filename = Filename
+module Filename_set = Filename_set
 module Hashtbl = Hashtbl
 module Table = Table
 module Int = Int
@@ -65,6 +66,7 @@ module Comparable = Comparable
 module Comparable_intf = Comparable_intf
 module Staged = Staged
 module String = String
+module String_builder = String_builder
 module Bool = Bool
 module Sexp = Sexp
 module Path = Path
@@ -108,6 +110,7 @@ module Bytes_unit = Bytes_unit
 module Dev_null = Dev_null
 module Platform = Platform
 module Per_item = Per_item
+module Bit_set = Bit_set
 
 module type Per_item = Per_item_intf.S
 
